/**
 * Defines a tag used by entries in a gallery-list/project-list,
 * used for filtering entries from view
 */
export type EntryTag = {
  /**
   * specifies a category that the tag belongs to
   * in order to optionally organize them in the view;
   * if category is not specified, tags will be assigned
   * "NoCategory" and organized into a section without a heading
   * placed before any other sections formed by categories (if any)
   */
  category?: string
  /**
   * specifies the name that the tag will appear as in the DOM;
   * if not specified, the id of the tag will be used in its place
   */
  displayName?: string
}

/**
 * Defines the list of tags in a gallery-list/project-list,
 * a key-value object where the value is the entry,
 * and the key represents the id of a tag;
 * the id of a tag must be unique,
 * and the ids specified in a gallery/project entry must match
 * the ids specified in `EntryTagCollection` in order for them to work effectively
 */
export type EntryTagCollection = { [id: string]: EntryTag }
